@@ -6,9 +6,12 @@ from glob import glob
 
 import twacapic.templates
 import yaml
+from loguru import logger
 from twacapic.auth import get_api
 from TwitterAPI.TwitterError import TwitterConnectionError, TwitterRequestError
 
+logger.remove()
+
 
 class UserGroup:
 
@@ -67,7 +70,7 @@ class UserGroup:
 
             response = api.request(f'users/:{user_id}/tweets', params)
 
-            print(response.text)
+            logger.debug(response.text)
 
             assert response.status_code == 200
 
@@ -75,21 +78,20 @@ class UserGroup:
 
             if 'errors' in tweets:
 
-                if tweets['errors'][0]['type'] == "https://api.twitter.com/2/problems/resource-not-found":
-
-                    print(f"WARNING: User {tweets['errors'][0]['value']} not found.")
-
+                if 'data' not in tweets:
+                    logger.error(tweets["errors"])
                     return None
 
-                if tweets['errors'][0]['type'] == "https://api.twitter.com/2/problems/not-authorized-for-resource":
+                for error in tweets['errors']:
+                    logger.warning(error)
 
-                    print(f"WARNING: User {tweets['errors'][0]['value']} is protected.")
-
-                    return None
-
-            if tweets['meta']['result_count'] == 0:
+            result_count = tweets['meta']['result_count']
 
+            if result_count == 0:
+                logger.info(f'No new tweets found for {user_id}.')
                 return None
+            else:
+                logger.info(f'{result_count} tweets found for {user_id}')
 
             oldest_id = tweets['meta']['oldest_id']
             newest_id = tweets['meta']['newest_id']
@@ -136,7 +138,7 @@ class UserGroup:
             params['tweet.fields'] = ','.join(fields)
             params['expansions'] = ','.join(expansions)
 
-            print(f"Collecting tweets for user {user_id} …")
+            logger.info(f"Collecting tweets for user {user_id} …")
 
             meta_file_path = f'{self.path}/{user_id}/meta.yaml'
 
@@ -161,7 +163,11 @@ class UserGroup:
                     user_metadata = yaml.safe_load(metafile)
 
                 params['max_results'] = max_results_per_call
-                params['since_id'] = user_metadata['newest_id']
+
+                try:
+                    params['since_id'] = user_metadata['newest_id']
+                except KeyError:
+                    pass
 
                 collected_ids = self.request_tweets(api, user_id, params, get_all_pages=True)
 
@@ -187,7 +193,7 @@ def retry(func):
 
             except (TwitterConnectionError, TwitterRequestError, AssertionError) as e:
 
-                print(e)
+                logger.warning(e)
 
                 if tries < max_tries:
 
@@ -196,10 +202,10 @@ def retry(func):
                     sleep_seconds = min(((tries * 2) ** 2), max(900 - total_sleep_seconds, 30))
                     total_sleep_seconds = total_sleep_seconds + sleep_seconds
                 else:
-                    print('Maximum retries reached. Raising Exception …')
+                    logger.exception('Maximum retries reached. Raising Exception …')
                     raise e
 
-                print(f"Retry in {sleep_seconds} seconds …")
+                logger.warning(f"Retry in {sleep_seconds} seconds …")
                 time.sleep(sleep_seconds)
                 continue
 
